<?php

namespace YdBc\BigCommerce;

use YdBc\BigCommerce\MiddlewareNotFoundException;

class Core {

    static function getEndpointURL() {
        return get_option('lightrcommerce_bc_endpoint_url');
    }

    static function getApiUrl() {
        return rtrim(self::getEndpointURL(), '/') . '/api/';
    }

    static function getOutput(string $endpoint) {
        if (strpos($endpoint, self::getEndpointURL()) !== 0) {
            $endpoint = rtrim(self::getEndpointURL(), '/') . '/' . $endpoint;
        }

        // https://developer.wordpress.org/plugins/http-api/
        // https://developer.wordpress.org/plugins/http-api/#wordpress-transients
        $response = wp_safe_remote_get($endpoint);
        $status = wp_remote_retrieve_response_code($response);
        $body = wp_remote_retrieve_body($response);

        if ($status >= 400) {
            throw new \Exception("Call to '$endpoint' failed with status $status", $status);
        }

        $body = preg_replace('#<html lang="\w+">#', '<html>', $body);

        $body = str_replace(
                ['<!DOCTYPE html><html><head>', '</head>', '</html>'],
                '',
                $body
        );
        $body = str_replace(
                'src="/_next',
                'src="' . self::getEndpointURL() . '_next',
                $body
        );
        $body = str_replace(
                'href="/_next',
                'href="' . self::getEndpointURL() . '_next',
                $body
        );

        return $body;
    }

    static function getConfig() {
        return self::callApi('config');
    }

    static function getProducts() {
        return self::callApi('products');
    }

    static function getCategories() {
        return self::callApi('categories');
    }

    static function getApiResponse(string $endpoint, string $method = 'get', array $options = []) {
        // call to any of the functions of wp_remote_*
        // see https://developer.wordpress.org/plugins/http-api/
        $function = sprintf('wp_remote_%s', strtolower($method));
        return $function($endpoint, $options);
    }

    static function callApi(
            string $endpoint,
            array $options = [],
            bool $returnJsonResponse = true
    ) {
        // https://developer.wordpress.org/plugins/http-api/
        // https://developer.wordpress.org/plugins/http-api/#wordpress-transients
        $response = self::getApiResponse(self::getApiUrl() . $endpoint, 'get', $options);
        $status = wp_remote_retrieve_response_code($response);
        $body = wp_remote_retrieve_body($response);

        switch ($status) {
            case 200:
                return $returnJsonResponse ? json_decode($body) : $body;

            case 404:
                throw new MiddlewareNotFoundException();

            default:
                throw new \Exception("Call to '$endpoint' failed with status $status", $status);
                break;
        }
    }

    function callBigCommerce(string $endpoint, $data = [], $method = 'GET') {
        $options = [
            'method' => $method,
            'headers' => [
                'accept' => 'application/json',
                'cache-control' => 'no-cache',
                'content-type' => 'application/json',
                'x-auth-token' => self::ACCESS_TOKEN,
            ],
            'body' => $data
        ];

        $response = wp_remote_request($endpoint, $options);
        $status = wp_remote_retrieve_response_code($response);
        $body = wp_remote_retrieve_body($response);

        return [
            'status' => $status,
            'data' => json_decode($body),
        ];
    }
}
