<?php

namespace YdBc\Plugin;

use YdBc\Plugin\Helper;

class Admin {

    public function __construct() {
        add_action('admin_menu', [$this, 'addMenuPages']);
        add_action('admin_init', [$this, 'registerSettingFields']);

        add_action('admin_enqueue_scripts', function () {
            wp_enqueue_script('ajax_script', LIGHTRCOMMERCE_ASSETS_URL . '/js/wizard.js', ['jquery']);
        });

        $this->addLinksToPluginsList();
    }

    public function registerSettingFields() {
        add_settings_section(
                'lightrcommerce_general_section',
                'General Settings',
                null,
                'lightrcommerce'
        );
        add_settings_field(
                'lightrcommerce_bc_endpoint_url',
                'Endpoint URL',
                [$this, 'optionOutput'],
                'lightrcommerce',
                'lightrcommerce_general_section',
                ['code' => 'lightrcommerce_bc_endpoint_url']
        );
        add_settings_field(
                'lightrcommerce_api_key',
                'api_key',
                [$this, 'optionOutput'],
                'lightrcommerce',
                'lightrcommerce_general_section',
                ['code' => 'lightrcommerce_api_key']
        );
        register_setting('lightrcommerce_general_group', 'lightrcommerce_bc_endpoint_url');
        register_setting('lightrcommerce_general_group', 'lightrcommerce_api_key');

        add_settings_section(
                'lightrcommerce_catalog_section',
                'Catalog Settings',
                null,
                'lightrcommerce'
        );
        add_settings_field(
                'lightrcommerce_bc_catalog_page',
                'Catalog Page',
                [$this, 'optionOutput'],
                'lightrcommerce',
                'lightrcommerce_catalog_section',
                ['code' => 'lightrcommerce_bc_catalog_page']
        );
        register_setting('lightrcommerce_catalog_group', 'lightrcommerce_bc_catalog_page');
    }

    public function addMenuPages() {
        if (Helper::isSetupCompleted()) {
            add_menu_page(
                    'LightR Commerce',
                    'LightR Commerce',
                    'manage_options',
                    'lightrcommerce',
                    [$this, 'loadOverviewPage'],
                    'dashicons-cart',
                    6
            );
        } else {
            add_menu_page(
                    'LightR Commerce',
                    'LightR Commerce',
                    'manage_options',
                    'lightrcommerce_wizard',
                    [$this, 'loadWizardPage'],
                    'dashicons-cart',
                    6
            );
        }

        if (\YdBc\Plugin\Helper::isSetupCompleted()) {
            add_submenu_page('lightrcommerce', __('Overview', 'lightrcommerce') . ' - LightrCommerce', 'Overview', 'manage_options', 'lightrcommerce', [$this, 'loadOverviewPage']);
            add_submenu_page('lightrcommerce', 'BigCommerce - LightrCommerce', 'BigCommerce', 'manage_options', 'lightrcommerce_bigcommerce', [$this, 'loadBigCommercePage']);
            add_submenu_page('lightrcommerce', 'Shopify - LightrCommerce', 'Shopify', 'manage_options', 'lightrcommerce_shopify', [$this, 'loadShopifyPage']);
            add_submenu_page('lightrcommerce', 'Magento - LightrCommerce', 'Magento', 'manage_options', 'lightrcommerce_magento', [$this, 'loadMagentoPage']);
            add_submenu_page('lightrcommerce', __('Setup Wizard', 'lightrcommerce') . ' - LightrCommerce', 'Setup Wizard', 'manage_options', 'lightrcommerce_wizard', [$this, 'loadWizardPage']);
            add_submenu_page('lightrcommerce', __('Support', 'lightrcommerce') . ' - LightrCommerce', 'Support', 'manage_options', 'lightrcommerce_support', [$this, 'loadSupportPage']);
        }

        add_submenu_page('lightrcommerce - hidden', 'Support - LightrCommerce', 'Support', 'manage_options', 'lightrcommerce_unsupported', [$this, 'loadUnsupportedPlatformPage']);
        add_submenu_page('lightrcommerce - hidden', 'See you soon - LightrCommerce', 'See you soon', 'manage_options', 'lightrcommerce_see_you_soon', [$this, 'loadSeeYouSoonPage']);
    }

    private function _loadPage(string $pageName) {
        $path = sprintf('%ssrc/templates/%s.php', LIGHTRCOMMERCE_PATH, $pageName);

        echo Helper::loadPartial('_wrapper_before');
        include $path;
        echo Helper::loadPartial('_wrapper_after');
    }

    public function loadOverviewPage() {
        return $this->_loadPage('dashboard');
    }

    public function loadBigCommercePage() {
        return $this->_loadPage('bigcommerce');
    }

    public function loadMagentoPage() {
        return $this->_loadPage('magento');
    }

    public function loadShopifyPage() {
        return $this->_loadPage('shopify');
    }

    public function loadWizardPage() {
        return $this->_loadPage('wizard');
    }

    public function loadSupportPage() {
        return $this->_loadPage('support');
    }

    public function loadUnsupportedPlatformPage() {
        return $this->_loadPage('unsupported_platform');
    }

    public function loadSeeYouSoonPage() {
        return $this->_loadPage('see_you_soon');
    }

    public function optionOutput($args) {
        $code = $args['code'];
        $value = get_option($code);
        echo "<input type='text' name='$code' value='$value' />";
    }

    /**
     * Adds links to the list of plugins available at Backend > Plugins > Installed Plugins
     */
    public function addLinksToPluginsList() {
        add_filter('plugin_action_links_' . LIGHTRCOMMERCE_PLUGIN_BASE, function ($links) {
            $url = esc_url(add_query_arg('page', 'lightrcommerce_support', get_admin_url() . 'admin.php'));

            $settings_link = sprintf('<a href="%s">%s</a>', $url, __('Support', 'lightrcommerce'));

            array_unshift(
                    $links,
                    $settings_link
            );

            if (Helper::isSetupCompleted()) {
                $url = esc_url(add_query_arg(
                                'page',
                                'lightrcommerce',
                                get_admin_url() . 'admin.php'
                ));

                $settings_link = sprintf('<a href="%s">%s</a>', $url, __('Configuration', 'lightrcommerce'));
            } else {
                $url = esc_url(add_query_arg(
                                'page',
                                'lightrcommerce_wizard',
                                get_admin_url() . 'admin.php'
                ));

                $settings_link = sprintf('<a href="%s">%s</a>', $url, __('Complete configuration wizard', 'lightrcommerce'));
            }

            array_unshift(
                    $links,
                    $settings_link
            );

            $response = wp_remote_get('https://api.lightrcommerce.com/api/plugin/wordpress', [
                'timeout' => 2
            ]);
            
            if (!is_wp_error($response)) {
                $body = @json_decode(wp_remote_retrieve_body($response));

                if (isset($body->version) && version_compare(LIGHTRCOMMERCE_VERSION, $body->version, '<')) {
                    $links[] = sprintf('<a href="%s" download style="font-weight: bold; white-space: nowrap">Update to version %s</a>', $body->url, $body->version);
                }
            }

            return $links;
        });
    }
}
